| Title: | Handle Zotero Local Database |
|---|---|
| Description: | Makes a connection to the (local) Zotero database (SQLite) to extract bibliographic references metadata. |
| Authors: | Nicolas Casajus [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-5537-5294>) |
| Maintainer: | Nicolas Casajus <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-18 08:40:45 UTC |
| Source: | https://github.com/FRBCesab/zoteror |
Retrieves references metadata from Zotero local database (SQLite).
get_zotero_data(path = "~/zotero")get_zotero_data(path = "~/zotero")
path |
a |
A data.frame with references in row and the following variables:
item_id: the identifier of the publication in the Zotero database;
library_type: the type of the library. Can be user (My library)
or group (Group libraries);
group: the name of the group library;
collection: the name of the library collection;
category: the category of the publication (article, book,
book_section, report, etc.);
year: the year of the publication;
title: the title of the publication;
author: the authors of the publication;
journal: the journal of the publication (only for article);
book_title: the title of the book (only for book_section);
editor: the editors of the book (only for book and book_section);
abstract: the abstract of the publication;
volume: the volume of the publication (only for article);
issue: the issue of the publication (only for article);
pages: the pages of the publication;
publisher: the publisher name;
place: the location of the publisher;
institution: the institution name;
doi: the DOI (Digital Object Identifier) of the publication;
url: the URL of the publication;
note: the annotations associated to the publication (only the PUBID
is retrieved).
## Not run: references <- zoteror::get_zotero_data() ## End(Not run)## Not run: references <- zoteror::get_zotero_data() ## End(Not run)